@@ -98,6 +98,12 @@ void ShortcutsTest::testShortcuts_data()
                                                               << std::make_pair(QEvent::KeyRelease, (Qt::ControlModifier | Qt::Key_Alt).toCombined())
                                                               << std::make_pair(QEvent::KeyRelease, Qt::Key_Control))
                                                  << true;
+    QTest::newRow("modifier-only multiple mods trigger when released out of order")
+        << QKeySequence(Qt::ControlModifier | Qt::AltModifier)
+        << (Events() << std::make_pair(QEvent::KeyPress, Qt::Key_Alt) << std::make_pair(QEvent::KeyPress, (Qt::AltModifier | Qt::Key_Control).toCombined())
+                     << std::make_pair(QEvent::KeyRelease, (Qt::ControlModifier | Qt::Key_Alt).toCombined())
+                     << std::make_pair(QEvent::KeyRelease, Qt::Key_Control))
+        << true;
     QTest::newRow("modifier-only multiple mods does not trigger modifier-only single mod")
         << QKeySequence(Qt::ControlModifier)
         << (Events() << std::make_pair(QEvent::KeyPress, Qt::Key_Control) << std::make_pair(QEvent::KeyPress, (Qt::ControlModifier | Qt::Key_Alt).toCombined())
@@ -112,6 +118,14 @@ void ShortcutsTest::testShortcuts_data()
                      << std::make_pair(QEvent::KeyPress, (Qt::ControlModifier | Qt::Key_Alt).toCombined())
                      << std::make_pair(QEvent::KeyRelease, (Qt::AltModifier | Qt::Key_Control).toCombined()) << std::make_pair(QEvent::KeyRelease, Qt::Key_Alt))
         << true;
+    QTest::newRow("modifier-only multiple mods trigger when any mod is released")
+        << QKeySequence(Qt::ControlModifier | Qt::ShiftModifier)
+        << (Events() << std::make_pair(QEvent::KeyPress, Qt::Key_Control)
+                     << std::make_pair(QEvent::KeyPress, (Qt::ControlModifier | Qt::Key_Shift).toCombined())
+                     << std::make_pair(QEvent::KeyRelease, (Qt::ControlModifier | Qt::Key_Shift).toCombined())
+                     << std::make_pair(QEvent::KeyPress, (Qt::ControlModifier | Qt::Key_Alt).toCombined())
+                     << std::make_pair(QEvent::KeyRelease, (Qt::AltModifier | Qt::Key_Control).toCombined()) << std::make_pair(QEvent::KeyRelease, Qt::Key_Alt))
+        << true;
     QTest::newRow("mod+pointer does not trigger modifier-only single mod")
         << QKeySequence(Qt::ControlModifier)
         << (Events() << std::make_pair(QEvent::KeyPress, Qt::Key_Control) << std::make_pair(QEvent::MouseButtonPress, Qt::LeftButton)
